unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls,
  Spin;

type

  { TForm1 }

  TForm1 = class(TForm)
    Button1: TButton;
    Button2: TButton;
    Button3: TButton;
    Label1: TLabel;
    Memo1: TMemo;
    SpinEdit1: TSpinEdit;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
  private
    procedure CreateThumbnail(ASrcFileName, ADestFileName: String;
      AssignToPicture: Boolean);

  public

  end;

var
  Form1: TForm1;

implementation

{$R *.lfm}

uses
  LCLIntf;

{ TForm1 }

procedure TForm1.Button1Click(Sender: TObject);
const
  W = 1920;
  H = 1080;
  NUM_LINES = 100;
var
  bmp: TBitmap;
  t: TDateTime;
  i, j: Integer;
begin
  if not DirectoryExists('images') then
    CreateDir('images');
  RandSeed := 0;
  Memo1.Lines.Add('Creating ' + IntToStr(SpinEdit1.Value) + ' images...');
  t := Now;
  for i:=1 to SpinEdit1.Value do begin
    bmp := TBitmap.Create;
    try
      bmp.SetSize(W, H);
      bmp.Canvas.Brush.Color := rgb(random(256), random(256), random(256));
      bmp.Canvas.fillRect(0, 0, W, H);
//      bmp.Canvas.Pen.Style := psSolid;
      for j := 1 to NUM_LINES do begin
        bmp.Canvas.Pen.Color := rgb(random(256), random(256), random(256));
        bmp.Canvas.Line(Random(W), Random(H), Random(W), Random(H));
      end;
      bmp.SaveToFile('images\bmp'+IntToStr(i)+'.bmp');
    finally
      bmp.Free;
    end;
  end;
  t := Now - t;
  Memo1.Lines.Add('Done in ' + FormatDateTime('s.zzz s', t));
end;

procedure TForm1.Button2Click(Sender: TObject);
var
  t: TDateTime;
  i: Integer;
begin
  Memo1.Lines.Add('Creating '+IntToStr(SpinEdit1.Value)+' thumbnail images...');
  t := Now;
  for i:=1 to SpinEdit1.Value do
    CreateThumbnail(
      'images\bmp'+IntToStr(i)+'.bmp',
      'images\thumb'+IntToStr(i)+'.bmp',
      false);
  t := Now - t;
  Memo1.Lines.Add('Done in ' + FormatDateTime('s.zzz" s"', t));
end;

procedure TForm1.Button3Click(Sender: TObject);
var
  t: TDateTime;
  i: Integer;
begin
  Memo1.Lines.Add('Creating '+IntToStr(SpinEdit1.Value)+' thumbnail images (assign to picture)...');
  t := Now;
  for i:=1 to SpinEdit1.Value do
    CreateThumbnail(
      'images\bmp'+IntToStr(i)+'.bmp',
      'images\thumb'+IntToStr(i)+'.bmp',
      true);
  t := Now - t;
  Memo1.Lines.Add('Done in ' + FormatDateTime('s.zzz" s"', t));
end;

procedure TForm1.CreateThumbnail(ASrcFileName, ADestFileName: String;
  AssignToPicture: Boolean);
const
  Wth = 192;
  Hth = 108;
var
  pic: TPicture;
  bmp: TBitmap;
  thumb: TBitmap;
begin
  bmp := TBitmap.Create;
  try
    bmp.LoadFromFile(ASrcFileName);

    if AssignToPicture then begin
      pic := TPicture.Create;
      try
        pic.Bitmap := bmp;
      finally
        pic.Free;
      end;
    end;

    thumb := TBitmap.Create;
    try
      thumb.SetSize(Wth, Hth);
      thumb.Canvas.StretchDraw(Rect(0, 0, Wth, Hth), bmp);
      thumb.SaveToFile(ADestFileName);
    finally
      thumb.Free;
    end;
  finally
    bmp.Free;
  end;
end;



end.

